Integrator
==========

.. currentmodule:: spdcalc.spdcalc

.. autoclass:: Integrator
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~Integrator.adaptive_simpson
      ~Integrator.clenshaw_curtis
      ~Integrator.default
      ~Integrator.gauss_konrod
      ~Integrator.gauss_legendre
      ~Integrator.simpson

   .. rubric:: Methods Documentation

   .. automethod:: adaptive_simpson
   .. automethod:: clenshaw_curtis
   .. automethod:: default
   .. automethod:: gauss_konrod
   .. automethod:: gauss_legendre
   .. automethod:: simpson
